function love.load()
	info={
		ox=0,oy=0,			--old mouse pos
		rx=0,ry=0,			--release mouse pos
		width=love.graphics.getWidth(),
		height=love.graphics.getHeight(),
		shot_num=1,
	}
	
	objDefs={
		{i=nil,							r=2,	ox=1,  oy=1,	pts=0,},
    }
	
	world=love.physics.newWorld(2000,2000)
	world:setGravity(0,0)
	
	-- Set wall on edge of window
	top={}
	top.b=love.physics.newBody(world,info.width/2,3,0,0)
	top.s=love.physics.newRectangleShape(top.b,0,0,info.width,6)
	top.s:setData('top')
	bottom={}
	bottom.b=love.physics.newBody(world,info.width/2,info.height+3,0,0)
	bottom.s=love.physics.newRectangleShape(bottom.b,0,0,info.width,6)
	bottom.s:setData('bottom')
	left={}
	left.b=love.physics.newBody(world,-3,info.height/2,0,0)
	left.s=love.physics.newRectangleShape(left.b,0,0,6,info.height)
	left.s:setData('left')
	right={}
	right.b=love.physics.newBody(world,info.width-3,info.height/2,0,0)
	right.s=love.physics.newRectangleShape(right.b,0,0,6,info.height)
	right.s:setData('right')
	
	shots={}
	shot_list={}
		
end

function love.update(dt)
	world:update(dt)
end

function love.draw()
	for i,v in pairs(shots) do
		if shot_list[i]==1 then
			love.graphics.circle('fill', v.body:getX(), v.body:getY(), v.shape:getRadius())
		end
	end

	local x1,y1, _,_, x3,y3, _,_ = top.s:getBoundingBox()
    local w = x3-x1
    local h = y3-y1
	love.graphics.rectangle('fill',top.b:getX()-w/2,top.b:getY(),w,h,0)
	local x1,y1, _,_, x3,y3, _,_ = bottom.s:getBoundingBox()
    local w = x3-x1
    local h = y3-y1
	love.graphics.rectangle('fill',bottom.b:getX()-w/2,bottom.b:getY(),w,h,0)
	local x1,y1, _,_, x3,y3, _,_ = right.s:getBoundingBox()
    local w = x3-x1
    local h = y3-y1
	love.graphics.rectangle('fill',right.b:getX(),right.b:getY()-h/2,w,h,0)
	local x1,y1, _,_, x3,y3, _,_ = left.s:getBoundingBox()
    local w = x3-x1
    local h = y3-y1
	love.graphics.rectangle('fill',left.b:getX(),left.b:getY()-h/2,w,h,0)
	
	-- Displays the line from pull start to pull release
	if love.mouse.isDown('l') then
		love.graphics.setLine(1,'smooth')
		love.graphics.line(info.ox,info.oy,love.mouse:getX(),love.mouse:getY())
	end
end

function love.keypressed(k)
	if k=='escape' then
        love.event.push('q')
    end
	if (love.keyboard.isDown('ralt')==true or love.keyboard.isDown('lalt')==true) then
		if k=='f4' then
			love.event.push('q')
		end
	end
end

function love.mousepressed(x, y, button)
	if button=='l' then
		info.ox=x
		info.oy=y
	end
end

function love.mousereleased(x, y, button)
	if button=='l' then
		fireSlingshot(objDefs[1],info.shot_num,x,y)
	end
end

function create_shot(def,i)
	info.shot_num=info.shot_num+1
	if info.shot_num>5 then	--change this number to controll number of balls on screen at a time
		info.shot_num=1
	end
	shots[i]={}
	shots[i].body=love.physics.newBody(world,10,-10)
	shots[i].shape=love.physics.newCircleShape(shots[i].body,def.r)
	shots[i].shape:setData('shot'..i)
	shots[i].image=def.i
	shots[i].offx=def.ox
	shots[i].offy=def.oy
	shots[i].pts=def.pts
	-- Restitution is the elastity of an object aka metal vs rubber, higher is more 'bouncey'
	shots[i].shape:setRestitution(0.25)
	-- Set Mass (x offset, y offset, mass in Kg, rotational inertia Kg/m2)
	shots[i].body:setMass(0,0,0.025,15)
	-- Bullet object continous collision detection rather than during update detection at time intervals of dt
	shots[i].body:setBullet(true)
	shot_list[i]=1
end

function fireSlingshot(def,i,x,y)
	info.rx=x info.ry=y
	create_shot(def,i)

	-- Reset the shot to the location of the release with no initial velocity
	shots[i].body:setPosition(x,y)
	shots[i].body:setLinearVelocity(0,0)
	shots[i].body:setAngularVelocity(0)
	
	-- Only if there is movement between pull and release
	if not(x==info.ox and y==info.oy) then
		local hyp,angle,xf,yf,xforce,yforce
		hyp=math.sqrt(math.pow((x-info.ox),2)+math.pow((y-info.oy),2))
		-- If it is a straight line apply force in the correct direction
		if (info.ox-x==0) then
			if (info.oy>y) then
				yforce=hyp
				xforce=0
			else
				yforce=hyp*-1
				xforce=0
			end
		elseif (y-info.oy==0) then
			if (info.ox>x) then
				xforce=hyp
				yforce=0
			else
				xforce=hyp*-1
				yforce=0
			end
		else
			if (0<(info.ox-x) and 0<=(y-info.oy)) then		--Q1
				angle=math.atan((y-info.oy)/(info.ox-x))	--fires Q1
				angle=math.abs(angle)+(math.pi*0)
			elseif (0>=(info.ox-x) and 0<=(y-info.oy)) then	--Q2
				angle=math.atan((info.ox-x)/(y-info.oy))	--fires Q2
				angle=math.abs(angle)+(math.pi*0.5)
			elseif (0>=(info.ox-x) and 0>(y-info.oy)) then	--Q3
				angle=math.atan((y-info.oy)/(info.ox-x))	--fires Q3
				angle=math.abs(angle)+(math.pi*1)
			elseif (0<(info.ox-x) and 0>(y-info.oy)) then	--Q4
				angle=math.atan((info.ox-x)/(y-info.oy))	--fire Q4
				angle=math.abs(angle)+(math.pi*1.5)
			end
			xforce=(math.cos(angle)*hyp)
			yforce=(math.sin(angle)*hyp)*-1	--negative because the y axis is flipped in love
		end
		-- Apply the force as an impulse to the shot
		shots[i].body:applyImpulse(xforce/200,yforce/200)
	end
end